@@ -17,12 +17,18 @@
 # 操作失败。
 FAILEDOPERATION = 'FailedOperation'
 
+# 操作失败。
+FAILEDOPERATION_CHECKIFSUPPORTPODSTRETCH = 'FailedOperation.CheckIfSupportPodStretch'
+
 # 重复的订单，请检查emr控制台。
 FAILEDOPERATION_DUPLICATEORDERNOTALLOWED = 'FailedOperation.DuplicateOrderNotAllowed'
 
 # 操作失败，不支持pod。
 FAILEDOPERATION_NOTSUPPORTPOD = 'FailedOperation.NotSupportPod'
 
+# 操作失败。
+FAILEDOPERATION_REFUNDCVMFAILED = 'FailedOperation.RefundCvmFailed'
+
 # 内部错误。
 INTERNALERROR = 'InternalError'
 
@@ -56,6 +62,9 @@ INTERNALERROR_CONFIGCGWERROR = 'InternalError.ConfigCgwError'
 # 内部服务调用异常。
 INTERNALERROR_CVMERROR = 'InternalError.CvmError'
 
+# 调用EKS报错。
+INTERNALERROR_EKSERROR = 'InternalError.EKSError'
+
 # 内部服务调用异常。
 INTERNALERROR_KMSERROR = 'InternalError.KmsError'
 
@@ -98,6 +107,9 @@ INVALIDPARAMETER_INCORRECTCOMMONCOUNT = 'InvalidParameter.IncorrectCommonCount'
 # Master节点数量无效。
 INVALIDPARAMETER_INCORRECTMASTERCOUNT = 'InvalidParameter.IncorrectMasterCount'
 
+# 不合法的AllNodeResourceSpec参数。
+INVALIDPARAMETER_INVALIDALLNODERESOURCESPEC = 'InvalidParameter.InvalidAllNodeResourceSpec'
+
 # 无效参数，AppId。
 INVALIDPARAMETER_INVALIDAPPID = 'InvalidParameter.InvalidAppId'
 
@@ -137,6 +149,9 @@ INVALIDPARAMETER_INVALIDCOUNTNUM = 'InvalidParameter.InvalidCountNum'
 # 错误信息：Invalid PodParameter。
 INVALIDPARAMETER_INVALIDCUSTOMIZEDPODPARAM = 'InvalidParameter.InvalidCustomizedPodParam'
 
+# DependService和EnableKerberos参数冲突。
+INVALIDPARAMETER_INVALIDDEPENDSERVICEANDENABLEKERBEROSCONFLICT = 'InvalidParameter.InvalidDependServiceAndEnableKerberosConflict'
+
 # 无效的磁盘大小。
 INVALIDPARAMETER_INVALIDDISKSIZE = 'InvalidParameter.InvalidDiskSize'
 
@@ -152,6 +167,9 @@ INVALIDPARAMETER_INVALIDFAILUREPOLICY = 'InvalidParameter.InvalidFailurePolicy'
 # 无效参数，EMR实例不符合要求。
 INVALIDPARAMETER_INVALIDINSTANCE = 'InvalidParameter.InvalidInstance'
 
+# 不合法的实例计费模式。
+INVALIDPARAMETER_INVALIDINSTANCECHARGETYPE = 'InvalidParameter.InvalidInstanceChargeType'
+
 # 无效的集群名称。
 INVALIDPARAMETER_INVALIDINSTANCENAME = 'InvalidParameter.InvalidInstanceName'
 
@@ -200,15 +218,24 @@ INVALIDPARAMETER_INVALIDPRODUCT = 'InvalidParameter.InvalidProduct'
 # 无效的产品ID。
 INVALIDPARAMETER_INVALIDPRODUCTID = 'InvalidParameter.InvalidProductId'
 
+# 不合法的产品版本。
+INVALIDPARAMETER_INVALIDPRODUCTVERSION = 'InvalidParameter.InvalidProductVersion'
+
 # 无效的项目ID。
 INVALIDPARAMETER_INVALIDPROJECTID = 'InvalidParameter.InvalidProjectId'
 
+# 不合法自动续费标识。
+INVALIDPARAMETER_INVALIDRENEWFLAG = 'InvalidParameter.InvalidRenewFlag'
+
 # 资源ID无效。
 INVALIDPARAMETER_INVALIDRESOURCEIDS = 'InvalidParameter.InvalidResourceIds'
 
 # 无效的资源规格。
 INVALIDPARAMETER_INVALIDRESOURCESPEC = 'InvalidParameter.InvalidResourceSpec'
 
+# 不合法的引导脚本执行参数。
+INVALIDPARAMETER_INVALIDSCRIPTBOOTSTRAPACTIONCONFIG = 'InvalidParameter.InvalidScriptBootstrapActionConfig'
+
 # 该EMR版本不支持开启安全模式。
 INVALIDPARAMETER_INVALIDSECURITYSUPPORT = 'InvalidParameter.InvalidSecuritySupport'
 
@@ -266,6 +293,9 @@ INVALIDPARAMETER_INVALIDVPCID = 'InvalidParameter.InvalidVpcId'
 # 无效的可用区。
 INVALIDPARAMETER_INVALIDZONE = 'InvalidParameter.InvalidZone'
 
+# 不合法的支持Kerberos标识。
+INVALIDPARAMETER_KERBEROSSUPPORT = 'InvalidParameter.KerberosSupport'
+
 # 无效参数，不满足必须组件。
 INVALIDPARAMETER_NOTCONTAINMUSTSELECTSOFTWARE = 'InvalidParameter.NotContainMustSelectSoftware'
 
@@ -299,6 +329,9 @@ INVALIDPARAMETERVALUE_INVALIDTKEINSTANCE = 'InvalidParameterValue.InvalidTkeInst
 # 引导脚本数量超过限制。
 LIMITEXCEEDED_BOOTSTRAPACTIONSNUMLIMITEXCEEDED = 'LimitExceeded.BootstrapActionsNumLimitExceeded'
 
+# 安全组数量超过限制。
+LIMITEXCEEDED_SECURITYGROUPNUMLIMITEXCEEDED = 'LimitExceeded.SecurityGroupNumLimitExceeded'
+
 # 缺少参数错误。
 MISSINGPARAMETER = 'MissingParameter'
 
@@ -347,6 +380,9 @@ RESOURCESSOLDOUT_CBSSOLDOUT = 'ResourcesSoldOut.CbsSoldOut'
 # 云服务器已售罄。
 RESOURCESSOLDOUT_CVMSOLDOUT = 'ResourcesSoldOut.CvmSoldOut'
 
+# 校验账号操作无权限。
+UNAUTHORIZEDOPERATION_CHECKCAMAUTH = 'UnauthorizedOperation.CheckCamAuth'
+
 # 未知参数错误。
 UNKNOWNPARAMETER = 'UnknownParameter'
 
